<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>Arqiver::AboutDialog</name>
    <message>
        <location filename="../../about.ui" line="160"/>
        <source>License</source>
        <translation>Llicència</translation>
    </message>
</context>
<context>
    <name>Arqiver::Backend</name>
    <message>
        <location filename="../../backends.cpp" line="840"/>
        <source>This file is a link but its target does not exist.</source>
        <translation>El fitxer és un enllaç però el destí no existeix.</translation>
    </message>
    <message>
        <location filename="../../backends.cpp" line="1261"/>
        <location filename="../../backends.cpp" line="1293"/>
        <location filename="../../backends.cpp" line="1337"/>
        <source>Could not read archive</source>
        <translation>No s&apos;ha pogut llegit l&apos;arxiu</translation>
    </message>
    <message>
        <location filename="../../backends.cpp" line="1296"/>
        <location filename="../../backends.cpp" line="1342"/>
        <source>Archive Loaded</source>
        <translation>S&apos;ha carregat l&apos;arxiu</translation>
    </message>
    <message>
        <location filename="../../backends.cpp" line="1303"/>
        <location filename="../../backends.cpp" line="1390"/>
        <source>Modification Finished</source>
        <translation>Modificació finalitzada</translation>
    </message>
    <message>
        <location filename="../../backends.cpp" line="1324"/>
        <location filename="../../backends.cpp" line="1359"/>
        <source>Extraction Finished</source>
        <translation>Extracció completada</translation>
    </message>
    <message>
        <location filename="../../backends.cpp" line="1327"/>
        <location filename="../../backends.cpp" line="1378"/>
        <source>Extraction Failed</source>
        <translation>L&apos;extracció ha fallat</translation>
    </message>
    <message>
        <location filename="../../backends.cpp" line="1475"/>
        <source>%1 is missing from your system.
Please install it for this kind of archive!</source>
        <translation>%1 no està instal·lat en el sistema.
Instal·leu-lo per treballar amb aquest tipus d&apos;arxius.</translation>
    </message>
</context>
<context>
    <name>Arqiver::LineEdit</name>
    <message>
        <location filename="../../lineedit.h" line="33"/>
        <source>You could type inside the main view.
Clear text with the Escape key.</source>
        <translation>Podeu escriure dins de la vista principal.
Esborra el text amb la tecla d&apos;escapament.</translation>
    </message>
</context>
<context>
    <name>Arqiver::PrefDialog</name>
    <message>
        <location filename="../../pref.ui" line="14"/>
        <source>Preferences</source>
        <translation>Preferències</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="50"/>
        <source>Start with this size:</source>
        <translation>Inicia amb aquesta mida:</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="118"/>
        <source>Use system icons where possible</source>
        <translation>Fes servir icones del sistema on sigui possible</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="125"/>
        <source>Show prompt on removing items</source>
        <translation>Mostra la pregunta en eliminar elements</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="132"/>
        <source>If this is unchecked, only the top level directories will be expanded.</source>
        <translation>Si no la marqueu, només s&apos;expandiran les carpetes pare.</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="135"/>
        <source>Expand all directories when opening archives</source>
        <translation>En obrir un arxiu, expandeix totes les carpetes</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="147"/>
        <location filename="../../pref.ui" line="160"/>
        <source>Leave empty for the default.

Warning: Arqiver will not work if the
binary does not belong to libarchive.</source>
        <translation>Deixeu-ho buit per defecte.

Avís: Arqiver no funcionarà si 
el binari no pertany a la libarchive.</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="153"/>
        <source>libarchive binary:</source>
        <translation>biblioteca libarchive:</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="38"/>
        <source>Remember window &amp;size on closing</source>
        <translation>Recorda la &amp;mida de la finestra en sortir</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="93"/>
        <source>Size of view icons:</source>
        <translation>Mida de les icones de visualització:</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="62"/>
        <source>px</source>
        <translation>píxels</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="184"/>
        <source>Application restart is needed for changes to take effect.</source>
        <translation>Cal reiniciar l&apos;aplicació perquè els canvis tinguin efecte.</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="241"/>
        <source>Select libarchive binary</source>
        <translation>Selecciona el binari de libarchive</translation>
    </message>
</context>
<context>
    <name>Arqiver::mainWin</name>
    <message>
        <location filename="../../mainWin.ui" line="53"/>
        <source>Archive:</source>
        <translation>Arxiu:</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="106"/>
        <source>Filter Files...</source>
        <translation>Filtra els fitxers...</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="129"/>
        <source>&amp;File</source>
        <translation>&amp;Fitxer</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="140"/>
        <source>&amp;Edit</source>
        <translation>&amp;Edita</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="155"/>
        <source>&amp;View</source>
        <translation>&amp;Vista</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="166"/>
        <source>&amp;Help</source>
        <translation>&amp;Ajuda</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="204"/>
        <source>&amp;Open Archive</source>
        <translation>&amp;Obre un arxiu</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="207"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="212"/>
        <source>&amp;New Archive</source>
        <translation>&amp;Nou arxiu</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="215"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="220"/>
        <source>&amp;Quit</source>
        <translation>&amp;Surt</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="223"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="228"/>
        <source>Add File(s)</source>
        <translation>Afegeix fitxer(s)</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="233"/>
        <source>Remove File(s)</source>
        <translation>Elimina fitxer(s)</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="238"/>
        <source>Extract All</source>
        <translation>Extreu-ho tot</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="241"/>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="246"/>
        <source>Add Directory</source>
        <translation>Afegeix una carpeta</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="251"/>
        <source>Extract Selection</source>
        <translation>Extreu els seleccionats</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="256"/>
        <source>Set Password</source>
        <translation>Estableix una contrasenya</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="261"/>
        <source>E&amp;xpand</source>
        <translation>E&amp;xpandeix</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="264"/>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Maj+Baix</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="269"/>
        <source>Collap&amp;se</source>
        <translation>Cont&amp;rau</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="272"/>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Maj+Amunt</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="277"/>
        <source>&amp;About</source>
        <translation>&amp;Quant a</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="282"/>
        <source>&amp;Copy Current Path</source>
        <translation>&amp;Copia el camí actual</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="287"/>
        <source>&amp;Preferences</source>
        <translation>&amp;Preferències</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="292"/>
        <source>Stop &amp;Process</source>
        <translation>Interromp el &amp;procés</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="295"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="305"/>
        <source>Update Archive</source>
        <translation>Actualitza l&apos;arxiu</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="147"/>
        <source>Root</source>
        <translation>Arrel</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="252"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="323"/>
        <source>File</source>
        <translation>Fitxer</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="323"/>
        <source>MimeType</source>
        <translation>Tipus MIME</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="323"/>
        <source>Size</source>
        <translation>Mida</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="553"/>
        <location filename="../../mainWin.cpp" line="838"/>
        <location filename="../../mainWin.cpp" line="882"/>
        <source>Opening Archive...</source>
        <translation>S&apos;està obrint l&apos;arxiu...</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="767"/>
        <source>Create Archive</source>
        <translation>Crea un arxiu</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="464"/>
        <location filename="../../mainWin.cpp" line="793"/>
        <location filename="../../mainWin.cpp" line="992"/>
        <location filename="../../mainWin.cpp" line="1300"/>
        <source>Question</source>
        <translation>Pregunta</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="794"/>
        <source>The following archive already exists:</source>
        <translation>Aquest arxiu ja existeix:</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="796"/>
        <source>Do you want to replace it?
</source>
        <translation>Voleu reemplaçar-lo?
</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="830"/>
        <source>Open Archive</source>
        <translation>Obre un arxiu</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="897"/>
        <location filename="../../mainWin.cpp" line="904"/>
        <location filename="../../mainWin.cpp" line="941"/>
        <source>Add to Archive</source>
        <translation>Afegeix-lo a l&apos;arxiu</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="936"/>
        <location filename="../../mainWin.cpp" line="967"/>
        <location filename="../../mainWin.cpp" line="1252"/>
        <location filename="../../mainWin.cpp" line="1258"/>
        <source>Adding Items...</source>
        <translation>S&apos;estan afegint els elements...</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="993"/>
        <source>Do you want to remove the selected item(s)?
</source>
        <translation>Voleu suprimir el(s) element(s) seleccionat(s)?
</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1012"/>
        <source>Removing Items...</source>
        <translation>S&apos;estan suprimint els elements...</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1215"/>
        <location filename="../../mainWin.cpp" line="1230"/>
        <location filename="../../mainWin.cpp" line="1315"/>
        <location filename="../../mainWin.cpp" line="1329"/>
        <source>Extracting...</source>
        <translation>S&apos;està extraient...</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1056"/>
        <source>Copy Archive Path</source>
        <translation>Copi la ruta de l&apos;arxiu</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="465"/>
        <source>Some files have been modified.</source>
        <translation>Alguns fitxers s&apos;han modificat.</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="466"/>
        <source>Do you want to ignore the changes?
</source>
        <translation>Voleu ignorar els canvis?
</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="627"/>
        <source>All Types</source>
        <translation>Tots els tipus</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="637"/>
        <location filename="../../mainWin.cpp" line="661"/>
        <source>Uncompressed Archive</source>
        <translation>Arxiu sense comprimir</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="638"/>
        <location filename="../../mainWin.cpp" line="662"/>
        <source>GZip Compressed Archive</source>
        <translation>Arxiu comprimit amb GZip</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="639"/>
        <location filename="../../mainWin.cpp" line="663"/>
        <location filename="../../mainWin.cpp" line="664"/>
        <source>BZip Compressed Archive</source>
        <translation>Arxiu comprimit amb BZip</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="640"/>
        <location filename="../../mainWin.cpp" line="665"/>
        <source>BZip2 Compressed Archive</source>
        <translation>Arxiu comprimit amb BZip2</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="641"/>
        <location filename="../../mainWin.cpp" line="673"/>
        <source>LMZA Compressed Archive</source>
        <translation>Arxiu comprimit amb LMZA</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="642"/>
        <location filename="../../mainWin.cpp" line="670"/>
        <source>XZ Compressed Archive</source>
        <translation>Arxiu comprimit amb XZ</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="643"/>
        <location filename="../../mainWin.cpp" line="674"/>
        <source>Zstandard Compressed Archive</source>
        <translation>Arxiu comprimit amb Zstandard</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="644"/>
        <location filename="../../mainWin.cpp" line="676"/>
        <source>CPIO Archive</source>
        <translation>Arxiu CPIO</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="646"/>
        <location filename="../../mainWin.cpp" line="678"/>
        <source>AR Archive</source>
        <translation>Arxiu AR</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="648"/>
        <location filename="../../mainWin.cpp" line="680"/>
        <source>Zip Archive</source>
        <translation>Arxiu Zip</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="649"/>
        <location filename="../../mainWin.cpp" line="682"/>
        <source>Gzip Archive</source>
        <translation>Arxiu Gzip</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="650"/>
        <location filename="../../mainWin.cpp" line="681"/>
        <source>7-Zip Archive</source>
        <translation>Arxiu 7-Zip</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="666"/>
        <location filename="../../mainWin.cpp" line="667"/>
        <source>READ-ONLY: BZip Archive</source>
        <translation>Només de lectura: arxiu BZip</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="668"/>
        <source>READ-ONLY: BZip2 Archive</source>
        <translation>Només de lectura: arxiu BZip2</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="669"/>
        <source>READ-ONLY: BZip2 Compressed PDF Document</source>
        <translation>Només de lectura: document PDF comprimit amb BZip2</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="671"/>
        <source>READ-ONLY: XZ archive</source>
        <translation>Només de lectura: arxiu XZ</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="672"/>
        <source>READ-ONLY: XZ Compressed PDF Document</source>
        <translation>Només de lectura: document PDF comprimit amb XZ</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="675"/>
        <source>READ-ONLY: Zstandard archive</source>
        <translation>Només de lectura: arxiu Zstandard</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="683"/>
        <source>Gzip Compressed PDF Document</source>
        <translation>PDF comprimit amb Gzip</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="684"/>
        <source>READ-ONLY: Compressed SVG Image</source>
        <translation>Només de lectura: SVG comprimit</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="685"/>
        <location filename="../../mainWin.cpp" line="686"/>
        <location filename="../../mainWin.cpp" line="687"/>
        <location filename="../../mainWin.cpp" line="688"/>
        <source>READ-ONLY: ISO Image</source>
        <translation>Només de lectura: imatge ISO</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="689"/>
        <source>READ-ONLY: XAR Archive</source>
        <translation>Només de lectura: arxiu XAR</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="690"/>
        <source>READ-ONLY: Java Archive</source>
        <translation>Només de lectura: arxiu Java</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="691"/>
        <source>READ-ONLY: Debian Package</source>
        <translation>Només de lectura: paquet Debian</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="692"/>
        <location filename="../../mainWin.cpp" line="693"/>
        <source>READ-ONLY: RedHat Package</source>
        <translation>Només de lectura: paquet RedHat</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="694"/>
        <location filename="../../mainWin.cpp" line="695"/>
        <location filename="../../mainWin.cpp" line="696"/>
        <source>READ-ONLY: MS Windows Executable</source>
        <translation>Només de lectura: executable de MS Windows</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="697"/>
        <source>READ-ONLY: MS Windows Installer Package</source>
        <translation>Només de lectura: paquet d&apos;instal·lació de MS Windows</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="698"/>
        <source>READ-ONLY: MS Windows Cabinet Archive</source>
        <translation>NOMÉS LECTURA: Arxiu del Cabinet MS Windows</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="700"/>
        <source>READ-ONLY: Android Package</source>
        <translation>Només de lectura: paquet d&apos;Android</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="701"/>
        <source>READ-ONLY: RAR Archive</source>
        <translation>Només de lectura: arxiu RAR</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="702"/>
        <source>READ-ONLY: AppImage application bundle</source>
        <translation>NOMÉS LECTURA: paquet d&apos;aplicacions AppImage</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="703"/>
        <source>READ-ONLY: VirtualBox Extension Pack</source>
        <translation>Només de lectura: paquet d&apos;extensions de VirtualBox</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="712"/>
        <source>All Known Types</source>
        <translation>Tots els tipus coneguts</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="717"/>
        <source>Show All Files</source>
        <translation>Mostra tots els fitxers</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1066"/>
        <source>Open Containing Folder</source>
        <translation>Obri la carpeta que el conté</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="300"/>
        <source>View Current Item</source>
        <translation>Visualitza l&apos;element actual</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1111"/>
        <location filename="../../mainWin.cpp" line="1119"/>
        <source>Enter Password</source>
        <translation>Inseriu la contrasenya</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1127"/>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1132"/>
        <source>OK</source>
        <translation>D&apos;acord</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1136"/>
        <source>Encrypt the file list</source>
        <translation>Xifra la llista de fitxers</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1137"/>
        <source>This will take effect after files/folders are added.</source>
        <translation>Tindrà efecte després que els fitxers/carpetes s&apos;hagin afegit.</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1208"/>
        <location filename="../../mainWin.cpp" line="1284"/>
        <source>Extract Into Directory</source>
        <translation>Extreu en la carpeta</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1301"/>
        <source>Some files will be overwritten.
Do you want to continue?
</source>
        <translation>Es sobreescriuran alguns fitxers.
Voleu continuar?
</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1427"/>
        <source>Link To: %1</source>
        <translation>Enllaç a: %1</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1694"/>
        <source>Could not read archive</source>
        <translation>No s&apos;ha pogut llegit l&apos;arxiu</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1765"/>
        <source>A simple Qt archive manager</source>
        <translation>Un senzill gestor d&apos;arxius amb Qt</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1766"/>
        <source>based on libarchive, gzip and 7z</source>
        <translation>basat en libarchive, gzip i 7z</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1767"/>
        <source>Author</source>
        <translation>Autor</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1768"/>
        <source>aka.</source>
        <translation>àlies</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1769"/>
        <location filename="../../mainWin.cpp" line="1770"/>
        <source>About Arqiver</source>
        <translation>Quant a l&apos;Arqiver</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1769"/>
        <source>Translators</source>
        <translation>Traductors</translation>
    </message>
</context>
</TS>
